'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var preact = require('preact');
var queryString = _interopDefault(require('query-string'));
var assign = _interopDefault(require('object-assign'));

function Image(_ref) {
  var src = _ref.src,
      _ref$steps = _ref.steps,
      steps = _ref$steps === undefined ? [250, 500, 750, 1000, 1500, 2000, 2500] : _ref$steps,
      _ref$sizes = _ref.sizes,
      sizes = _ref$sizes === undefined ? '100vw' : _ref$sizes,
      _ref$svg = _ref.svg,
      svg = _ref$svg === undefined ? false : _ref$svg,
      classes = _ref.classes,
      aspect_ratio = _ref.aspect_ratio,
      _ref$params = _ref.params,
      params = _ref$params === undefined ? {} : _ref$params,
      alt = _ref.alt;

  // set default params, merge user preferences with priority
  var opts = assign({
    fm: src.match(/\.(\w+)$/)[1],
    fit: aspect_ratio ? 'crop' : 'max',
    q: 80
  }, params);

  // handle aspect ratios & steps passed as a string
  aspect_ratio = typeof aspect_ratio === 'string' ? aspect_ratio.split(',').map(Number) : aspect_ratio;

  steps = typeof steps === 'string' ? steps.split(',').map(Number) : steps;

  if (svg && svg !== 'false') {
    // if it's an SVG, we don't need the picture element, so return
    return preact.h('img', { 'class': classes, src: src, alt: alt });
  } else {
    // otherwise, we return a picture element with multiple sizes and a webp
    // optimized version for performance
    var srcDefault = formatSteps(steps, opts, aspect_ratio, src);
    var srcWebp = formatSteps(steps, assign({}, opts, { fm: 'webp' }), aspect_ratio, src);

    return preact.h(
      'picture',
      null,
      preact.h('source', { type: 'image/webp', srcSet: srcWebp, sizes: sizes }),
      preact.h('img', {
        'class': classes,
        src: format(src, opts, aspect_ratio && aspect_ratio[2], aspect_ratio),
        srcSet: srcDefault,
        sizes: sizes,
        alt: alt
      })
    );
  }
}

function formatSteps(steps, opts, aspect_ratio, src) {
  return steps.map(function (s) {
    return format(src, opts, s, aspect_ratio) + ' ' + s + 'w';
  });
}

function format(src, opts, width, aspect_ratio) {
  var opt = assign({}, opts);
  if (width) opt.w = width;
  if (width && aspect_ratio) opt.h = aspect_ratio[1] / aspect_ratio[0] * width;
  return src + '?' + queryString.stringify(opt);
}

exports.default = Image;
exports.formatSteps = formatSteps;
exports.format = format;
